@@ -180,6 +180,7 @@ class OpenAPIParser(JsonSchemaParser):
         use_title_as_name: bool = False,
         http_headers: Optional[Sequence[Tuple[str, str]]] = None,
         use_annotated: bool = False,
+        use_non_positive_negative_number_constrained_types: bool = False,
     ):
         super().__init__(
             source=source,
@@ -222,6 +223,7 @@ class OpenAPIParser(JsonSchemaParser):
             use_title_as_name=use_title_as_name,
             http_headers=http_headers,
             use_annotated=use_annotated,
+            use_non_positive_negative_number_constrained_types=use_non_positive_negative_number_constrained_types,
         )
         self.open_api_scopes: List[OpenAPIScope] = openapi_scopes or [
             OpenAPIScope.Schemas
